aboutsummaryrefslogtreecommitdiff
path: root/lisp
diff options
context:
space:
mode:
Diffstat (limited to 'lisp')
-rw-r--r--lisp/.dir-locals.el7
1 files changed, 3 insertions, 4 deletions
diff --git a/lisp/.dir-locals.el b/lisp/.dir-locals.el
index bcb8ba5..da012d6 100644
--- a/lisp/.dir-locals.el
+++ b/lisp/.dir-locals.el
@@ -1,7 +1,6 @@
;;; Directory Local Variables
;;; For more information see (info "(emacs) Directory Variables")
-;; Preferred indentation style:
((nil . ((indent-tabs-mode . nil)))
- ;; setting this makes package-lint look in the main file for deps:
- (emacs-lisp-mode . ((package-lint-main-file . "mastodon.el"))))
+ (emacs-lisp-mode . ((elisp-flymake-byte-compile-load-path . load-path)
+ (package-lint-main-file . "mastodon.el"))))
@@ -1,7 +1,6 @@
-;;; Directory Local Variables
+;;; Directory Local Variables -*- no-byte-compile: t -*-
;;; For more information see (info "(emacs) Directory Variables")